==> huaweicloudsdkcloudtest-3.1.110-py2.py3-none-any.whl: huaweicloudsdkcloudtest/v1/model/list_cases_status_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCasesStatusResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'error': 'CommonResponseErrorOfobject',
        'result': 'QueryCasesStatusResponseV2',
        'status': 'str'
    }

    attribute_map = {
        'error': 'error',
        'result': 'result',
        'status': 'status'
    }

    def __init__(self, error=None, result=None, status=None):
        """ListCasesStatusResponse

        The model defined in huaweicloud sdk

        :param error: 
        :type error: :class:`huaweicloudsdkcloudtest.v1.CommonResponseErrorOfobject`
        :param result: 
        :type result: :class:`huaweicloudsdkcloudtest.v1.QueryCasesStatusResponseV2`
        :param status: 状态值，如success、error
        :type status: str
        """
        
        super(ListCasesStatusResponse, self).__init__()

        self._error = None
        self._result = None
        self._status = None
        self.discriminator = None

        if error is not None:
            self.error = error
        if result is not None:
            self.result = result
        if status is not None:
            self.status = status

    @property
    def error(self):
        """Gets the error of this ListCasesStatusResponse.

        :return: The error of this ListCasesStatusResponse.
        :rtype: :class:`huaweicloudsdkcloudtest.v1.CommonResponseErrorOfobject`
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this ListCasesStatusResponse.

        :param error: The error of this ListCasesStatusResponse.
        :type error: :class:`huaweicloudsdkcloudtest.v1.CommonResponseErrorOfobject`
        """
        self._error = error

    @property
    def result(self):
        """Gets the result of this ListCasesStatusResponse.

        :return: The result of this ListCasesStatusResponse.
        :rtype: :class:`huaweicloudsdkcloudtest.v1.QueryCasesStatusResponseV2`
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this ListCasesStatusResponse.

        :param result: The result of this ListCasesStatusResponse.
        :type result: :class:`huaweicloudsdkcloudtest.v1.QueryCasesStatusResponseV2`
        """
        self._result = result

    @property
    def status(self):
        """Gets the status of this ListCasesStatusResponse.

        状态值，如success、error

        :return: The status of this ListCasesStatusResponse.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ListCasesStatusResponse.

        状态值，如success、error

        :param status: The status of this ListCasesStatusResponse.
        :type status: str
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCasesStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcloudtest-3.1.157-py2.py3-none-any.whl: huaweicloudsdkcloudtest/v1/model/list_cases_status_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCasesStatusResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'error': 'CommonResponseErrorOfobject',
        'result': 'QueryCasesStatusResponseV2',
        'status': 'str'
    }

    attribute_map = {
        'error': 'error',
        'result': 'result',
        'status': 'status'
    }

    def __init__(self, error=None, result=None, status=None):
        r"""ListCasesStatusResponse

        The model defined in huaweicloud sdk

        :param error: 
        :type error: :class:`huaweicloudsdkcloudtest.v1.CommonResponseErrorOfobject`
        :param result: 
        :type result: :class:`huaweicloudsdkcloudtest.v1.QueryCasesStatusResponseV2`
        :param status: 状态值，如success、error
        :type status: str
        """
        
        super(ListCasesStatusResponse, self).__init__()

        self._error = None
        self._result = None
        self._status = None
        self.discriminator = None

        if error is not None:
            self.error = error
        if result is not None:
            self.result = result
        if status is not None:
            self.status = status

    @property
    def error(self):
        r"""Gets the error of this ListCasesStatusResponse.

        :return: The error of this ListCasesStatusResponse.
        :rtype: :class:`huaweicloudsdkcloudtest.v1.CommonResponseErrorOfobject`
        """
        return self._error

    @error.setter
    def error(self, error):
        r"""Sets the error of this ListCasesStatusResponse.

        :param error: The error of this ListCasesStatusResponse.
        :type error: :class:`huaweicloudsdkcloudtest.v1.CommonResponseErrorOfobject`
        """
        self._error = error

    @property
    def result(self):
        r"""Gets the result of this ListCasesStatusResponse.

        :return: The result of this ListCasesStatusResponse.
        :rtype: :class:`huaweicloudsdkcloudtest.v1.QueryCasesStatusResponseV2`
        """
        return self._result

    @result.setter
    def result(self, result):
        r"""Sets the result of this ListCasesStatusResponse.

        :param result: The result of this ListCasesStatusResponse.
        :type result: :class:`huaweicloudsdkcloudtest.v1.QueryCasesStatusResponseV2`
        """
        self._result = result

    @property
    def status(self):
        r"""Gets the status of this ListCasesStatusResponse.

        状态值，如success、error

        :return: The status of this ListCasesStatusResponse.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        r"""Sets the status of this ListCasesStatusResponse.

        状态值，如success、error

        :param status: The status of this ListCasesStatusResponse.
        :type status: str
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCasesStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
